Release 1.5
-----------

New Modules
^^^^^^^^^^^


Enhancements
^^^^^^^^^^^^

* Booststrap client - use unix:sockets by default on images with support (`344 <https://github.com/arista-eosplus/ztpserver/pull/344>`_) [`jerearista <https://github.com/jerearista>`_]
    .. comment
* Action install_image - support for disabling downgrade (`343 <https://github.com/arista-eosplus/ztpserver/pull/343>`_) [`jerearista <https://github.com/jerearista>`_]
    .. comment
* Resolve file download issues - disable gzip, deflate in HTTP requests (`342 <https://github.com/arista-eosplus/ztpserver/pull/342>`_) [`jerearista <https://github.com/jerearista>`_]
    .. comment

Fixed
^^^^^

* Fix "resource file missing" error on validate (`339 <https://github.com/arista-eosplus/ztpserver/issues/339>`_) [`urvishpanchal <https://github.com/urvishpanchal>`_]
    .. comment
* Docs - Fix setup.py install paths when on ReadTheDocs (`328 <https://github.com/arista-eosplus/ztpserver/pull/328>`_) [`jerearista <https://github.com/jerearista>`_]
    .. comment

Known Caveats
^^^^^^^^^^^^^


